@@ -29,7 +29,7 @@ SudokuSettings::SudokuSettings()
 */
 bool SudokuSettings::loadSettings(CSudokuTable* aSudokuTable)
 {
-	QFile data("/home/user/MyDocs/.masuddoku/sudokusettings.txt");
+	QFile data("/home/user/MyDocs/.masudoku/sudokusettings.txt");
 	if (data.open(QFile::ReadOnly)) {
 		QDataStream in(&data);
 		in >> iBackgroundColor;
@@ -73,7 +73,7 @@ bool SudokuSettings::loadSettings(CSudokuTable* aSudokuTable)
 */	
 bool SudokuSettings::saveSettings(CSudokuTable* aSudokuTable)
 {
-	QFile data("/home/user/MyDocs/.masuddoku/sudokusettings.txt");
+	QFile data("/home/user/MyDocs/.masudoku/sudokusettings.txt");
 	if (data.open(QFile::WriteOnly)) {
 		QDataStream out(&data);
 		out << iBackgroundColor;
