@@ -3,7 +3,7 @@
   Project: masudoku
   Platform: Fremantle (maemo5)
   Author: Petri Kultanen pete@petnetti.net
-  Last Edit: 15.2.2010
+  Last Edit: 3.6.2010
   Note: Original project: pudoku for s60 nokia phones By Petri Kultanen.
 */
 #include "sudokutable.h"
@@ -18,7 +18,7 @@ CSudokuTable::CSudokuTable()
 CSudokuTable::~CSudokuTable()
 {
 }
-//Generate new game. this can take long time if aAmount is >53 if it is >56 this funcktion may newer return.
+//Generate new game.  if aAmount is >53 if it is >56 this funcktion may newer return.
 void CSudokuTable::newGame(int aAmount)
 {
     clearTable();
@@ -620,7 +620,16 @@ void CSudokuTable::removeMemoryNumbers(int aCol, int aRow)
 {
     memoryTable[aCol][aRow]=0;
 }
-
+//---------------------------------------------------------------------------
+qint32 CSudokuTable::getMemoryDataNum(int aCol,int aRow)
+{
+	return memoryTable[aCol][aRow];
+}
+//---------------------------------------------------------------------------
+void CSudokuTable::setMemoryDataNum(qint32 aNum, int aCol, int aRow)
+{
+memoryTable[aCol][aRow] = aNum;
+}
 //---------------------------------------------------------------------------
 void CSudokuTable::loadFromFileL(bool aAuto)
 {
